from netbox.filtersets import NetBoxModelFilterSet

from netbox_storage.models import StorageConfiguration


class StorageConfigurationFilter(NetBoxModelFilterSet):
    """Filter capabilities for LogicalVolume instances."""

    class Meta:
        model = StorageConfiguration
        fields = [
            "virtual_machine"
        ]




from netbox.views import generic

from netbox_storage.filters.storageconfiguration import StorageConfigurationFilter
from netbox_storage.forms import (
    StorageConfigurationFilterForm, StorageConfigurationForm
)

from netbox_storage.models import StorageConfiguration
from netbox_storage.tables import StorageConfigurationTable


class StorageConfigurationListView(generic.ObjectListView):
    queryset = StorageConfiguration.objects.all()
    filterset = StorageConfigurationFilter
    filterset_form = StorageConfigurationFilterForm
    table = StorageConfigurationTable


class StorageConfigurationView(generic.ObjectView):
    """Display PhysicalVolume details"""

    queryset = StorageConfiguration.objects.all()


class StorageConfigurationEditView(generic.ObjectEditView):
    """View for editing a PhysicalVolume instance."""

    queryset = StorageConfiguration.objects.all()
    form = StorageConfigurationForm
    default_return_url = "plugins:netbox_storage:storageconfiguration_list"


class StorageConfigurationDeleteView(generic.ObjectDeleteView):
    queryset = StorageConfiguration.objects.all()
    default_return_url = "plugins:netbox_storage:storageconfiguration_list"



from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)
from netbox_storage.models import StorageConfiguration
from utilities.forms import (
    CSVModelChoiceField,
    DynamicModelChoiceField,
)
from virtualization.models import VirtualMachine


class StorageConfigurationForm(NetBoxModelForm):
    virtual_machine = DynamicModelChoiceField(
        queryset=VirtualMachine.objects.all(),
        help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
    )

    fieldsets = (
        (
            "Drive Cluster Config",
            (
                "virtual_machine",
            ),
        ),
    )

    class Meta:
        model = StorageConfiguration

        fields = (
            "virtual_machine",
        )


class StorageConfigurationFilterForm(NetBoxModelFilterSetForm):
    model = StorageConfiguration

    virtual_machine = DynamicModelChoiceField(
        queryset=VirtualMachine.objects.all(),
        required=False
    )


class StorageConfigurationImportForm(NetBoxModelImportForm):
    virtual_machine = CSVModelChoiceField(
        queryset=VirtualMachine.objects.all(),
        required=False,
        to_field_name='name',
        help_text='Required'
    )

    class Meta:
        model = StorageConfiguration

        fields = (
            "virtual_machine",
        )


class StorageConfigurationBulkEditForm(NetBoxModelBulkEditForm):
    model = StorageConfiguration

    virtual_machine = CSVModelChoiceField(
        queryset=VirtualMachine.objects.all(),
        required=False,
        to_field_name='name',
        help_text='Required'
    )

    fieldsets = (
        (
            None,
            ["virtual_machine"],
        ),
    )



from netbox.tables import (
    NetBoxTable,
    ToggleColumn,
)

from netbox_storage.models import StorageConfiguration


class StorageConfigurationTable(NetBoxTable):
    pk = ToggleColumn()

    class Meta(NetBoxTable.Meta):
        model = StorageConfiguration
        fields = (
            "pk",
        )
        default_columns = (
            "pk",
        )
